===========================
Changes in version 2016.2.0
===========================

FFC 2016.2.0 was released on 2016-11-30.

Summary of changes
==================

- Generalize ufc interface to non-affine parameterized coordinates
- Add ``ufc::coordinate_mapping`` class
- Make ufc interface depend on C++11 features requiring gcc version >= 4.8
- Change the mapping ``pullback as metric`` to ``double covariant piola`` (this
  preserves tangential-tangential trace).
- Added Hellan-Herrmann-Johnson element as supported element
- Add mapping ``double contravariant piola`` (this preserves normal-normal
  trace).
- Include comment with effective representation and integral metadata
  to generated ``tabulate_tensor`` code


Detailed changes
================

- Jit compiler now compiles elements separately from forms to avoid duplicate work
- Add parameter max_signature_length to optionally shorten signatures in the jit cache
- Move uflacs module into ffc.uflacs
- Remove installation of pkg-config and CMake files (UFC path and
  compiler flags are available from ffc module)
- Add dependency on dijitso and remove dependency on instant
- Add experimental Bitbucket pipelines
- Tidy the repo after UFC and UFLACS merge, and general spring cleanup. This
  includes removal of instructions how to merge two repos, commit hash
  c8389032268041fe94682790cb773663bdf27286.
